<?php namespace EscapeWork\Manager\Downloads\Controllers;

use EscapeWork\Manager\Controllers\ManagerController;
use EscapeWork\Manager\Downloads\Repositories\DownloadCategoryRepository;
use EscapeWork\Manager\Downloads\Models\DownloadCategory;
use View, Input, Redirect, Config;

class DownloadCategoriesController extends ManagerController
{

    public function __construct(DownloadCategoryRepository $downloadCategory)
    {
        parent::__construct();

        $this->downloadCategory = $downloadCategory;

        # filters
        $this->validatePermissions('download_categories');
    }

    public function index()
    {
        return View::make('manager-downloads::downloads.categories.index', [
            'downloadCategories' => $this->downloadCategory->paginate(20),
        ]);
    }

    public function create()
    {
        $this->downloadCategory->fill(Input::old());

        return View::make('manager-downloads::downloads.categories.form', [
            'downloadCategory' => $this->downloadCategory,
            'edit'             => false,
        ]);
    }

    public function store()
    {
        $this->downloadCategory->fill(Input::all());

        if (! $this->downloadCategory->validate()) {
            return Redirect::route('manager.downloads.categories.create')
                        ->withInput()
                        ->withErrors($this->download->messages());
        }

        $this->downloadCategory->save();

        return Redirect::route('manager.downloads.categories.index')
                       ->with('message', 'A categoria <strong>' . $this->downloadCategory->title . '</strong> foi inserida com sucesso!');
    }

    public function edit($id)
    {
        $this->downloadCategory->findOrFail($id);

        return View::make('manager-downloads::downloads.categories.form', [
            'downloadCategory' => $this->downloadCategory,
            'edit'             => true,
        ]);
    }

    public function update($id)
    {
        $this->downloadCategory->findOrFail($id);
        $this->downloadCategory->fill(Input::all());

        if (! $this->downloadCategory->validate()) {
            return Redirect::route('manager.downloads.categories.edit', array($this->downloadCategory->id))
                    ->withInput()
                    ->withErrors($this->download->messages());
        }

        $this->downloadCategory->save();

        return Redirect::route('manager.downloads.categories.index')
                ->with('message', 'A categoria <strong>'.$this->downloadCategory->title.'</strong> foi editada com sucesso!');
    }

    public function destroy($id)
    {
        $this->downloadCategory->findOrFail($id);
        $this->downloadCategory->destroy($id);

        return Redirect::route('manager.downloads.categories.index')
                ->with('message', 'A categoria <strong>'.$this->downloadCategory->title.'</strong> foi excluída com sucesso!');
    }
}
