<?php namespace EscapeWork\Manager\Downloads\Controllers;

use EscapeWork\Manager\Controllers\ManagerController;
use EscapeWork\Manager\Downloads\Repositories\DownloadCategoryRepository;
use EscapeWork\Manager\Downloads\Repositories\DownloadRepository;
use EscapeWork\Manager\Downloads\Models\Download;
use View, Input, Redirect, Config;

class DownloadsController extends ManagerController
{

    public function __construct(
        DownloadRepository $download,
        DownloadCategoryRepository $downloadCategory)
    {
        parent::__construct();

        $this->download         = $download;
        $this->downloadCategory = $downloadCategory;

        # filters
        $this->validatePermissions('downloads');
    }

    public function index()
    {
        return View::make(Config::get('manager-downloads::views.downloads.index'), [
            'downloads' => $this->download->paginate(20),
        ]);
    }

    public function create()
    {
        $this->download->fill(Input::old());

        return View::make(Config::get('manager-downloads::views.downloads.form'), [
            'downloadCategories' => $this->downloadCategory->get(),
            'download'           => $this->download,
            'edit'               => false,
        ]);
    }

    public function store()
    {
        $this->download->fill(Input::all());

        if (Input::has('thumb')) {
            $this->download->uploadThumb(Input::file('thumb'));
        }

        if (Input::has('file')) {
            $this->download->uploadFile(Input::file('file'));
        }

        if (! $this->download->validate()) {
            return Redirect::route('manager.downloads.create')
                        ->withInput()
                        ->withErrors($this->download->messages());
        }

        $this->download->save();

        return Redirect::route('manager.downloads.index')
                       ->with('message', 'O download <strong>' . $this->download->title . '</strong> foi inserido com sucesso!');
    }

    public function edit($id)
    {
        $this->download->findOrFail($id);

        return View::make(Config::get('manager-downloads::views.downloads.form'), [
            'downloadCategories' => $this->downloadCategory->get(),
            'download'           => $this->download,
            'edit'               => true,
        ]);
    }

    public function update($id)
    {
        $this->download->findOrFail($id);
        $this->download->fill(Input::all());

        if (Input::hasFile('thumb')) {
            $this->download->uploadThumb(Input::file('thumb'));
        }

        if (Input::hasFile('file')) {
            $this->download->uploadFile(Input::file('file'));
        }

        if (! $this->download->validate()) {
            return Redirect::route('manager.downloads.edit', array($this->download->id))
                    ->withInput()
                    ->withErrors($this->download->messages());
        }

        $this->download->save();

        return Redirect::route('manager.downloads.index')
                ->with('message', 'O download <strong>'.$this->download->title.'</strong> foi editado com sucesso!');
    }

    public function destroy($id)
    {
        $this->download->findOrFail($id);
        $this->download->delete($id);

        return Redirect::route('manager.downloads.index')
                ->with('message', 'O download <strong>'.$this->download->title.'</strong> foi excluído com sucesso!');
    }
}
