@extends(Config::get('manager::views.layouts.master'))

@section('content')
    <ul class="breadcrumb">
        <li><a href="{{ route('manager.home') }}">Home</a></li>
        <li><a href="{{ route('manager.downloads.index') }}">Downloads</a></li>
        <li class="active">{{ $edit ? 'Editar' : 'Inserir' }}</li>
    </ul><!-- .breadcrumb -->

    <div class="page-header">
        <div class="pull-left">
            <h2>Downloads</h2>
        </div><!-- .pull-left -->

        <div class="pull-right">
            <a href="{{ route('manager.downloads.index') }}" class="btn btn-default">Cancelar</a>
        </div><!-- .pull-right -->

        <div class="clearfix"></div>
    </div><!-- .page-header -->

    @include('manager::inc.messages')

    <form action="{{ ! $edit ? route('manager.downloads.store') : route('manager.downloads.update', $download->id) }}" method="post" id="form-download" class="form-horizontal" enctype="multipart/form-data">
        @if ($edit)
            <input type="hidden" name="_method" value="put" />
        @endif

        <fieldset>
            @section('fields')
                <div class="form-group">
                    <label for="category_id" class="col-sm-2 control-label">Categorias</label>

                    <div class="col-sm-2">
                        <select name="category_id" id="category_id" class="form-control" autofocus required>
                            <option value="">Selecione</option>
                            @foreach($downloadCategories as $downloadCategory)
                                <option {{ ( $downloadCategory->id == $download->category_id ? 'selected' : '') }} value="{{ $downloadCategory->id }}">{{ $downloadCategory->title }}</option>
                            @endforeach
                        </select>
                    </div><!-- .controls -->
                </div><!-- .form-group -->

                <div class="form-group">
                    <label for="title" class="col-sm-2 control-label">Título</label>

                    <div class="col-sm-8">
                        <input type="text" name="title" id="title" class="form-control" value="{{ $download->title }}" required />
                    </div><!-- .controls -->
                </div><!-- .form-group -->

                <div class="form-group">
                    <label for="description" class="col-sm-2 control-label">Descrição</label>

                    <div class="col-sm-8">
                        <textarea  name="description" id="description" data-editor>{{ $download->description }}</textarea>
                    </div><!-- .controls -->
                </div><!-- .form-group -->

                <div class="form-group">
                    <label class="col-sm-2 control-label">Arquivo</label>

                    <div class="col-sm-8">
                        <input type="file" name="file" class="form-control" multiple/>
                    </div><!-- .controls -->
                </div><!-- .form-group -->

                @if ($edit && $download->file)
                    <div class="form-group">
                        <label class="col-sm-2 control-label">Arquivo deste download</label>

                        <div class="col-sm-8">
                                <p>
                                    <a href="{{ asset('files/downloads/' . $download->file) }}" class="btn" download="{{ $download->file }}" target="_blank">
                                        <span class="glyphicon glyphicon-download"></span> {{ $download->file }}
                                    </a>
                                </p>
                        </div><!-- .controls -->
                    </div><!-- .form-group -->
                @endif

                <div class="form-group">
                    <label for="thumb" class="col-sm-2 control-label">Thumb</label>

                    <div class="col-sm-8">
                        <input type="file" name="thumb" id="thumb" class="form-control" accept="image/jpeg,image/png" />

                        <span class="help-block">Apenas imagens <strong>jpg</strong> ou <strong>png</strong> são aceitas.</span>
                        @if (! is_null($download->thumb))
                            <span class="help-block">Apenas selecione se deseja alterar a thumb.</span>
                        @endif
                    </div><!-- .controls -->
                </div><!-- .form-group -->

                @if ($download->thumb)
                    <div class="form-group">
                        <label for="thumb" class="col-sm-2 control-label">Thumb atual</label>

                        <div class="col-sm-8">
                            <img src="{{ asset('files/downloads/' . $download->thumb) }}" style="width:70px;" alt="" />
                        </div><!-- .controls -->
                    </div><!-- .form-group -->
                @endif
            @show
        </fieldset>

        <div class="form-group">
            <div class="col-sm-offset-2 col-sm-10">
                <button type="submit" class="btn btn-primary js-btn-submit" data-loading-text="Carregando...">Salvar</button>
                <a href="{{ route('manager.downloads.index') }}" class="btn">Cancelar</a>
            </div>
        </div><!-- .form-actions -->
    </form>
@stop
